# 房源导入导出功能接口文档

## 1. 导出功能

### 1.1 导出单个房源

#### 接口描述
根据房源ID导出单个房源的详细信息为Excel文件。

#### 接口地址
```
GET /api/room/template/export/{id}
```

#### 请求参数
| 参数名 | 类型 | 必须 | 位置 | 描述 |
| ----- | --- | --- | --- | ---- |
| id | String | 是 | path | 房源ID |

#### 响应结果
Excel文件流，含有房源的基本信息、业主信息、招商信息和扩展信息。

#### 使用示例
```
GET /api/room/template/export/1234567890
```

### 1.2 批量导出房源

#### 接口描述
根据房源ID数组批量导出房源的详细信息为Excel文件。

#### 接口地址
```
POST /api/room/template/export/batch
```

#### 请求参数
| 参数名 | 类型 | 必须 | 位置 | 描述 |
| ----- | --- | --- | --- | ---- |
| ids | List<String> | 是 | body | 房源ID数组 |

#### 请求示例
```json
["1", "2", "3", "10", "15"]
```

> 注意：请求体必须是JSON数组格式，不要使用对象包装。

#### 响应结果
Excel文件流，含有多个房源的基本信息、业主信息、招商信息和扩展信息。

## 2. 导入功能

### 2.1 下载导入模板

#### 接口描述
下载房源导入的Excel模板，用户可以按照模板格式填写房源信息后进行导入。

#### 接口地址
```
GET /api/room/template/importTemplate
```

#### 请求参数
无

#### 响应结果
Excel文件流，包含预设的列名和示例数据。

### 2.2 批量导入房源

#### 接口描述
通过Excel文件批量导入房源数据，返回导入结果信息。

#### 接口地址
```
POST /api/room/template/import
```

#### 请求参数
| 参数名 | 类型 | 必须 | 位置 | 描述 |
| ----- | --- | --- | --- | ---- |
| file | MultipartFile | 是 | form-data | Excel文件 |

#### 响应结果
```json
{
  "code": 200,
  "msg": "导入成功",
  "data": {
    "successCount": 10,
    "failCount": 2,
    "failMsg": "第2行：项目[测试项目]不存在<br/>第5行：导入失败，原因：数据格式错误<br/>"
  }
}
```

#### 字段说明
| 字段名 | 类型 | 描述 |
| ----- | --- | ---- |
| successCount | Integer | 成功导入的记录数 |
| failCount | Integer | 导入失败的记录数 |
| failMsg | String | 导入失败的详细信息，包含行号和失败原因 |

## 3. 导入模板字段说明

| 字段名 | 必填 | 描述 | 示例值 |
| ----- | --- | ---- | ----- |
| 项目 | 是 | 项目名称，必须是系统中已存在的项目 | 智慧园区一期 |
| 楼宇 | 是 | 楼宇名称，必须是系统中已存在的楼宇 | A栋 |
| 楼层 | 是 | 楼层名称，必须是系统中已存在的楼层 | 3层 |
| 房号 | 是 | 房源编号，同一项目、楼宇、楼层下不能重复 | A301 |
| 房间数字编号 | 是 | 房间的数字编号，方便排序 | 301 |
| 计租面积 | 否 | 用于计算租金的面积，单位㎡ | 100 |
| 计费面积 | 否 | 用于计算物业费等费用的面积，单位㎡ | 100 |
| 建筑面积 | 否 | 房源的建筑面积，单位㎡ | 120 |
| 层高 | 否 | 房源的层高，单位m | 3.2 |
| 报价 | 否 | 房源的报价 | 5000 |
| 底价 | 否 | 房源的底价 | 4500 |
| 单位 | 否 | 价格单位 | 元/㎡/月 |
| 房源备案号 | 否 | 房源在政府部门的备案号 | GZ20230001 |
| 标签 | 否 | 房源的标签，多个标签用逗号分隔 | 临近地铁,带装修,拎包入住 |
| 房源管理编号 | 否 | 内部使用的房源管理编号 | ZH-A301 |
| 备注 | 否 | 房源的备注信息 | 适合科技企业入驻 |
| 默认图片 | 否 | 房源的默认图片URL | http://example.com/image.jpg |

## 4. 注意事项

1. 导入时，项目、楼宇、楼层必须是系统中已经存在的，否则导入会失败
2. 房号在同一项目、楼宇、楼层下不能重复
3. 导入的Excel文件必须符合模板格式，否则可能导致导入失败
4. 批量导出时，建议一次导出的房源数量不要过多，以免影响性能
5. 所有接口返回的Excel文件均为.xlsx格式 