package com.eden.common.utils;

import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.Date;

/**
 * 日期工具类
 */
public class DateUtils {
    
    /**
     * 日期格式 yyyy-MM-dd
     */
    public static final String DATE_PATTERN = "yyyy-MM-dd";
    
    /**
     * 日期时间格式 yyyy-MM-dd HH:mm:ss
     */
    public static final String DATETIME_PATTERN = "yyyy-MM-dd HH:mm:ss";
    
    /**
     * 将日期字符串转换为Date对象
     * 
     * @param dateStr 日期字符串
     * @return Date对象
     */
    public static Date parseDate(String dateStr) {
        if (dateStr == null || dateStr.trim().isEmpty()) {
            return null;
        }
        
        try {
            if (dateStr.length() <= 10) {
                return new SimpleDateFormat(DATE_PATTERN).parse(dateStr);
            } else {
                return new SimpleDateFormat(DATETIME_PATTERN).parse(dateStr);
            }
        } catch (ParseException e) {
            return null;
        }
    }
    
    /**
     * 将Date对象转换为日期字符串
     * 
     * @param date Date对象
     * @return 日期字符串
     */
    public static String formatDate(Date date) {
        if (date == null) {
            return null;
        }
        return new SimpleDateFormat(DATE_PATTERN).format(date);
    }
    
    /**
     * 将Date对象转换为日期时间字符串
     * 
     * @param date Date对象
     * @return 日期时间字符串
     */
    public static String formatDateTime(Date date) {
        if (date == null) {
            return null;
        }
        return new SimpleDateFormat(DATETIME_PATTERN).format(date);
    }
    
    /**
     * 获取当前日期字符串
     * 
     * @return 当前日期字符串
     */
    public static String getCurrentDate() {
        return formatDate(new Date());
    }
    
    /**
     * 获取当前日期时间字符串
     * 
     * @return 当前日期时间字符串
     */
    public static String getCurrentDateTime() {
        return formatDateTime(new Date());
    }
} 