package com.eden.common.utils;

import org.springframework.web.context.request.RequestContextHolder;
import org.springframework.web.context.request.ServletRequestAttributes;
import javax.servlet.http.HttpServletRequest;

/**
 * 安全工具类
 */
public class SecurityUtils {
    /**
     * 获取租户ID
     */
    public static String getTenantId() {
        ServletRequestAttributes attributes = (ServletRequestAttributes) RequestContextHolder.getRequestAttributes();
        if (attributes != null) {
            HttpServletRequest request = attributes.getRequest();
            String tenantId = request.getHeader("X-Tenant-ID");
            if (tenantId != null && !tenantId.isEmpty()) {
                return tenantId;
            }
        }
        // 返回默认租户ID，实际项目中应该从配置或其他地方获取
        return "default_tenant";
    }

    /**
     * 获取用户ID
     */
    public static String getUserId() {
        ServletRequestAttributes attributes = (ServletRequestAttributes) RequestContextHolder.getRequestAttributes();
        if (attributes != null) {
            HttpServletRequest request = attributes.getRequest();
            String userId = request.getHeader("X-User-ID");
            if (userId != null && !userId.isEmpty()) {
                return userId;
            }
        }
        // 返回默认用户ID，实际项目中应该从配置或其他地方获取
        return "system";
    }

    /**
     * 获取用户名
     */
    public static String getUsername() {
        ServletRequestAttributes attributes = (ServletRequestAttributes) RequestContextHolder.getRequestAttributes();
        if (attributes != null) {
            HttpServletRequest request = attributes.getRequest();
            String username = request.getHeader("X-Username");
            if (username != null && !username.isEmpty()) {
                return username;
            }
        }
        // 返回默认用户名，实际项目中应该从配置或其他地方获取
        return "system";
    }
} 