package com.eden.room.common;

import java.io.Serializable;

/**
 * 通用响应结果
 * @param <T> 数据类型
 */
public class Result<T> implements Serializable {
    private static final long serialVersionUID = 1L;
    
    /** 成功响应码 */
    public static  String SUCCESS = "0000000000000000";
    
    /** 失败响应码 */
    public static final String ERROR = "1";
    
    /** 响应码 */
    private String code;
    
    /** 响应消息 */
    private String message;
    
    /** 响应数据 */
    private T data;
    
    public Result() {
    }
    
    public Result(String code, String message) {
        this.code = code;
        this.message = message;
    }
    
    public Result(String code, String message, T data) {
        this.code = code;
        this.message = message;
        this.data = data;
    }
    
    /**
     * 成功返回结果
     * @param <T> 数据类型
     * @return 结果
     */
    public static <T> Result<T> success() {
        return new Result<T>(SUCCESS, "操作成功");
    }
    
    /**
     * 成功返回结果
     * @param <T> 数据类型
     * @param data 数据
     * @return 结果
     */
    public static <T> Result<T> success(T data) {
        return new Result<T>(SUCCESS, "操作成功", data);
    }
    
    /**
     * 成功返回结果
     * @param <T> 数据类型
     * @param message 消息
     * @param data 数据
     * @return 结果
     */
    public static <T> Result<T> success(String message, T data) {
        return new Result<T>(SUCCESS, message, data);
    }
    
    /**
     * 失败返回结果
     * @param <T> 数据类型
     * @return 结果
     */
    public static <T> Result<T> error() {
        return new Result<T>(ERROR, "操作失败");
    }
    
    /**
     * 失败返回结果
     * @param <T> 数据类型
     * @param message 消息
     * @return 结果
     */
    public static <T> Result<T> error(String message) {
        return new Result<T>(ERROR, message);
    }
    
    /**
     * 失败返回结果
     * @param <T> 数据类型
     * @param code 响应码
     * @param message 消息
     * @return 结果
     */
    public static <T> Result<T> error(String code, String message) {
        return new Result<T>(code, message);
    }
    
    /**
     * 失败返回结果
     * @param <T> 数据类型
     * @param message 消息
     * @param data 数据
     * @return 结果
     */
    public static <T> Result<T> error(String message, T data) {
        return new Result<T>(ERROR, message, data);
    }

    
    /**
     * 判断是否成功
     * @return 是否成功
     */
    public boolean isSuccess() {
        return SUCCESS.equals(code);
    }
    
    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }

    public String getMessage() {
        return message;
    }

    public void setMessage(String message) {
        this.message = message;
    }

    public T getData() {
        return data;
    }

    public void setData(T data) {
        this.data = data;
    }
} 