package com.eden.room.common.enums;

/**
 * 装修情况枚举
 */
public enum DecorationStatusEnum {
    
    /** 精装 */
    DELUXE("1","精装"),
    
    /** 简装 */
    SIMPLE("2","简装"),
    
    /** 毛坯 */
    ROUGH("3","毛坯"),
    
    /** 标准交付 */
    STANDARD("4","标准交付"),
    
    /** 豪装 */
    LUXURY("5","豪装");
    
    private final String value;

    public String getKey() {
        return key;
    }

    private final String key;

    DecorationStatusEnum(String key, String value) {
        this.value = value;
        this.key = key;
    }
    
    public String getValue() {
        return value;
    }
    
    /**
     * 根据值获取枚举
     *
     * @param value 枚举值
     * @return 枚举
     */
    public static DecorationStatusEnum getByValue(String value) {
        for (DecorationStatusEnum status : values()) {
            if (status.getKey().equals(value)) {
                return status;
            }
        }
        return null;
    }
    /**
     * 根据枚举获取值
     *
     * @param key
     * @return 枚举
     */
    public static String getValue(String key) {
        for (DecorationStatusEnum status : values()) {
            if (status.getKey().equals(key)) {
                return status.getValue();
            }
        }
        return null;
    }
    /**
     * 校验枚举值是否有效
     *
     * @param value 枚举值
     * @return 是否有效
     */
    public static boolean isValid(String value) {
        return getByValue(value) != null;
    }
} 