package com.eden.room.common.enums;

/**
 * 房源类型枚举
 */
public enum RoomTypeEnum {
    
    /** 办公 */
    OFFICE("1","办公"),
    
    /** 商业 */
    BUSINESS("2","商业"),
    
    /** 仓储 */
    STORAGE("3","仓储"),
    
    /** 厂房 */
    FACTORY("4","厂房"),
    
    /** 多经 */
    MULTI_ECONOMIC("5","多经"),
    
    /** 公寓 */
    APARTMENT("6","公寓"),
    
    /** 住宅 */
    RESIDENTIAL("7","住宅"),
    
    /** 其他 */
    OTHER("8","其他");
    
    private final String value;
    private final String key;

    public String getKey() {
        return key;
    }

    RoomTypeEnum(String key, String value) {
        this.value = value;
        this.key = key;
    }
    
    public String getValue() {
        return value;
    }
    
    /**
     * 根据值获取枚举
     *
     * @param value 枚举值
     * @return 枚举
     */
    public static RoomTypeEnum getByValue(String value) {
        for (RoomTypeEnum type : values()) {
            if (type.getKey().equals(value)) {
                return type;
            }
        }
        return null;
    }
    
    /**
     * 校验枚举值是否有效
     *
     * @param value 枚举值
     * @return 是否有效
     */
    public static boolean isValid(String value) {
        return getByValue(value) != null;
    }
} 