package com.eden.room.config;

import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;

import feign.Logger;
import feign.RequestInterceptor;
import feign.codec.ErrorDecoder;

/**
 * Feign客户端配置
 */
@Configuration
public class FeignConfig {

    /**
     * Feign日志级别配置
     */
    @Bean
    public Logger.Level feignLoggerLevel() {
        return Logger.Level.FULL;
    }
    
    /**
     * 请求拦截器，添加请求头
     */
    @Bean
    public RequestInterceptor requestInterceptor() {
        return requestTemplate -> {
            // 添加租户ID头
            requestTemplate.header("X-Tenant-ID", "DEFAULT_TENANT");
            // 可以添加其他通用请求头
        };
    }
    
    /**
     * 自定义错误解码器
     */
    @Bean
    public ErrorDecoder errorDecoder() {
        return new FeignErrorDecoder();
    }
    
    /**
     * 自定义Feign错误解码器
     */
    public class FeignErrorDecoder implements ErrorDecoder {
        private final ErrorDecoder defaultErrorDecoder = new Default();
        
        @Override
        public Exception decode(String methodKey, feign.Response response) {
            // 处理特定的错误，例如404、500等
            if (response.status() == 404) {
                return new RuntimeException("请求的资源不存在: " + methodKey);
            } else if (response.status() == 500) {
                return new RuntimeException("远程服务器错误: " + methodKey);
            }
            
            // 其他错误使用默认处理
            return defaultErrorDecoder.decode(methodKey, response);
        }
    }
} 