package com.eden.room.controller;

import java.util.List;

import com.eden.common.exception.ServiceException;
import com.eden.room.domain.Project;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import com.github.pagehelper.PageInfo;
import com.eden.common.core.controller.BaseController;
import com.eden.room.common.Result;
import com.eden.room.domain.Building;
import com.eden.room.service.IBuildingService;

/**
 * 楼宇信息Controller
 */
@RestController
@RequestMapping("/room/building")
public class BuildingController extends BaseController {
    @Autowired
    private IBuildingService buildingService;

    /**
     * 查询楼宇信息列表
     */
    @GetMapping("/list")
    public Result<PageInfo<Building>> list(Building building,
                                         @RequestParam(defaultValue = "1") Integer pageNum,
                                         @RequestParam(defaultValue = "10") Integer pageSize) {
        startPage(pageNum, pageSize);
        List<Building> list = buildingService.selectBuildingList(building);
        return getPageResult(list);
    }

    /**
     * 获取楼宇信息详细信息
     */
    @GetMapping(value = "/{id}")
    public Result<Building> getInfo(@PathVariable("id") Long id) {
        return success(buildingService.selectBuildingById(id));
    }

    /**
     * 新增楼宇信息
     */
    @PostMapping
    public Result<Integer> add(@RequestBody Building building) {
        if (buildingService.checkBuildingNameExists(building)) {
            return error("新增楼宇'" + building.getBuildingName() + "'失败，楼宇名称已存在");
        }
        int rows = buildingService.insertBuilding(building);
        return toResult(rows);
    }

    /**
     * 修改楼宇信息
     */
    @PutMapping
    public Result<Integer> edit(@RequestBody Building building) {
        int rows = buildingService.updateBuilding(building);
        return toResult(rows);
    }

    /**
     * 删除楼宇信息
     */
    @DeleteMapping("/{ids}")
    public Result<Integer> remove(@PathVariable String[] ids) {
        try {
            int rows = buildingService.deleteBuildingByIds(ids);
            return toResult(rows);
        } catch (RuntimeException e) {
            return error(e.getMessage());
        }
    }
    /**
     * 查询楼宇信息列表
     */
    @PostMapping("/getBuildByIds")
    public List<Building> list(@RequestBody List<String> ids) {

        List<Building> list = buildingService.getBuildByIds(ids);
        return list;
    }
    /**
     * 获取楼宇统计信息
     */
    @GetMapping("/{id}/statistics")
    public Result<Building> getStatistics(@PathVariable("id") Long id) {
        return success(buildingService.selectBuildingStatistics(id));
    }
} 