package com.eden.room.controller;

import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import com.eden.room.common.Result;
import com.eden.room.domain.dto.OwnerDTO;
import com.eden.room.feign.OwnerFeignClient;

/**
 * 业主信息控制器
 */
@RestController
@RequestMapping("/owner")
public class OwnerController {
    
    @Autowired
    private OwnerFeignClient ownerFeignClient;
    
    /**
     * 获取业主列表
     */
    @GetMapping("/list")
    public Result<List<OwnerDTO>> listOwners() {
        try {
            Result<List<OwnerDTO>> result = ownerFeignClient.listOwners();
            if (result.getCode() == Result.SUCCESS) {
                return Result.success(result.getData());
            } else {
                return Result.error(result.getMessage());
            }
        } catch (Exception e) {
            return Result.error("获取业主列表失败：" + e.getMessage());
        }
    }
    
    /**
     * 根据姓名搜索业主
     */
    @GetMapping("/search")
    public Result<List<OwnerDTO>> searchOwners(@RequestParam(required = false) String name) {
        try {
            Result<List<OwnerDTO>> result;
            if (name != null && !name.trim().isEmpty()) {
                result = ownerFeignClient.searchOwnersByName(name);
            } else {
                result = ownerFeignClient.listOwners();
            }
            
            if (result.getCode() == Result.SUCCESS) {
                return Result.success(result.getData());
            } else {
                return Result.error(result.getMessage());
            }
        } catch (Exception e) {
            return Result.error("搜索业主失败：" + e.getMessage());
        }
    }
} 