package com.eden.room.controller;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import com.github.pagehelper.PageInfo;
import com.eden.common.core.controller.BaseController;
import com.eden.room.common.Result;
import com.eden.room.domain.Project;
import com.eden.room.service.IProjectService;

/**
 * 项目信息Controller
 */
@RestController
@RequestMapping("/room/project")
public class ProjectController extends BaseController {
    @Autowired
    private IProjectService projectService;

    /**
     * 查询项目信息列表
     */
    @GetMapping("/list")
    public Result<PageInfo<Project>> list(Project project,
                                        @RequestParam(defaultValue = "1") Integer pageNum,
                                        @RequestParam(defaultValue = "10") Integer pageSize) {
        startPage(pageNum, pageSize);
        List<Project> list = projectService.selectProjectList(project);
        return getPageResult(list);
    }

    /**
     * 获取项目信息详细信息
     */
    @GetMapping(value = "/{id}")
    public Result<Project> getInfo(@PathVariable("id") String id) {
        return success(projectService.selectProjectById(id));
    }

    /**
     * 新增项目信息
     */
    @PostMapping
    public Result<Integer> add(@RequestBody Project project) {
        // 校验项目名称是否唯一
        if (projectService.checkProjectNameExists(project)) {
            return error("新增项目'" + project.getProjectName() + "'失败，项目名称已存在");
        }
        int rows = projectService.insertProject(project);
        return toResult(rows);
    }

    /**
     * 修改项目信息
     */
    @PutMapping
    public Result<Integer> edit(@RequestBody Project project) {
//        // 校验项目名称是否唯一
//        if (projectService.checkProjectNameExists(project)) {
//            return error("修改项目'" + project.getProjectName() + "'失败，项目名称已存在");
//        }
        int rows = projectService.updateProject(project);
        return toResult(rows);
    }

    /**
     * 删除项目信息
     */
    @DeleteMapping("/{ids}")
    public Result<Integer> remove(@PathVariable String[] ids) {
        try {
            int rows = projectService.deleteProjectByIds(ids);
            return toResult(rows);
        } catch (RuntimeException e) {
            return error(e.getMessage());
        }
    }

    /**
     * 获取项目统计信息
     */
    @GetMapping("/{id}/statistics")
    public Result<Project> getStatistics(@PathVariable("id") String id) {
        return success(projectService.selectProjectStatistics(id));
    }
    /**
     * 查询项目信息列表
     */
    @PostMapping("/selectByIds")
    public List<Project> list(@RequestBody List<String> ids) {

        List<Project> list = projectService.selectProjectListByIds(ids);
        return list;
    }
    /**
     * 查询项目信息列表
     */
    @PostMapping("/selectByName")
    public List<Project> list(@RequestBody String name) {

        List<Project> list = projectService.selectProjectListByName(name);
        return list;
    }
} 