package com.eden.room.domain;

import lombok.Data;
import lombok.EqualsAndHashCode;
import javax.validation.constraints.NotBlank;
import javax.validation.constraints.NotNull;
import javax.validation.constraints.DecimalMin;
import javax.validation.constraints.Digits;
import java.math.BigDecimal;
import javax.persistence.Table;
import javax.persistence.Column;
import javax.persistence.Id;

/**
 * 楼宇信息实体类
 */
@Data
@EqualsAndHashCode(callSuper = true)
@Table(name = "TB_BUILDING")
public class Building extends BaseEntity {
    private static final long serialVersionUID = 1L;

    /** 楼宇ID */
    @Id
    @Column(name = "id")
    private Long id;

    /** 租户ID */
    @Column(name = "tenant_id")
    //@NotBlank(message = "租户ID不能为空")
    private String tenantId;

    /** 所属项目ID */
    @Column(name = "project_id")
    @NotBlank(message = "所属项目ID不能为空")
    private String projectId;

    /** 项目名称 */
    private String projectName;

    /** 楼宇编号 */
    @Column(name = "building_code")
    @NotBlank(message = "楼宇编号不能为空")
    private String buildingCode;

    /** 楼宇名称 */
    @Column(name = "building_name")
    @NotBlank(message = "楼宇名称不能为空")
    private String buildingName;

    /** 所属地区 */
    @Column(name = "region")
    private String region;

    /** 楼宇地址 */
    @Column(name = "address")
    private String address;

    /** 产权性质 */
    @Column(name = "property_nature")
    @NotBlank(message = "产权性质不能为空")
    private String propertyNature;

    /** 不动产证编号 */
    @Column(name = "property_cert_no")
    private String propertyCertNo;

    /** 产权编号 */
    @Column(name = "property_no")
    private String propertyNo;

    /** 土地编号 */
    @Column(name = "land_no")
    private String landNo;

    /** 排序值 */
    @Column(name = "sort_order")
    private Integer sortOrder;

    /** 建筑面积 */
    @Column(name = "building_area")
    @NotNull(message = "建筑面积不能为空")
    private BigDecimal buildingArea;

    /** 产权面积 */
    @Column(name = "property_area")
    @NotNull(message = "产权面积不能为空")
    private BigDecimal propertyArea;

    /** 可租面积 */
    @Column(name = "rentable_area")
    private BigDecimal rentableArea;

    /** 自用面积 */
    @Column(name = "self_use_area")
    private BigDecimal selfUseArea;

    /** 配套面积 */
    @Column(name = "supporting_area")
    private BigDecimal supportingArea;

    /** 车位面积 */
    @Column(name = "parking_area")
    private BigDecimal parkingArea;

    /** 默认收支账户ID */
    @Column(name = "account_id")
    private String accountId;

    /** 楼宇标签 */
    @Column(name = "building_tags")
    private String buildingTags;

    /** 是否热门楼宇: 0-否，1-是 */
    @Column(name = "is_hot")
    private String isHot;

    /** 总楼层数 */
    @Column(name = "total_floors")
    private Integer totalFloors;

    /** 配套设施 */
    @Column(name = "facilities")
    private String facilities;

    /** 楼宇图片URL */
    @Column(name = "image_url")
    private String imageUrl;

    /** 总房源数量 */
    @NotNull(message = "总房源数量不能为空")
    private Integer totalRooms;

    /** 出租率 */
    @DecimalMin(value = "0", message = "出租率不能小于0")
    @Digits(integer = 5, fraction = 2, message = "出租率最多支持5位整数和2位小数")
    private BigDecimal rentalRate;

    /** 在租面积 */
    @DecimalMin(value = "0", message = "在租面积不能小于0")
    @Digits(integer = 10, fraction = 2, message = "在租面积最多支持10位整数和2位小数")
    private BigDecimal rentedArea;

    /** 在租合同数 */
    @NotNull(message = "在租合同数不能为空")
    private Integer rentedContracts;

    /** 待租面积 */
    @DecimalMin(value = "0", message = "待租面积不能小于0")
    @Digits(integer = 10, fraction = 2, message = "待租面积最多支持10位整数和2位小数")
    private BigDecimal waitingArea;

    /** 待租房间数 */
    @NotNull(message = "待租房间数不能为空")
    private Integer waitingRooms;

    // 显式提供getter方法，以防Lombok失效
    public String getBuildingName() {
        return this.buildingName;
    }
    
    public void setBuildingName(String buildingName) {
        this.buildingName = buildingName;
    }

    public String getBuildingCode() {
        return buildingCode;
    }

    public void setBuildingCode(String buildingCode) {
        this.buildingCode = buildingCode;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getTenantId() {
        return tenantId;
    }

    public void setTenantId(String tenantId) {
        this.tenantId = tenantId;
    }

    public String getProjectId() {
        return projectId;
    }

    public void setProjectId(String projectId) {
        this.projectId = projectId;
    }

    public String getRegion() {
        return region;
    }

    public void setRegion(String region) {
        this.region = region;
    }

    public String getAddress() {
        return address;
    }

    public void setAddress(String address) {
        this.address = address;
    }

    public String getPropertyNature() {
        return propertyNature;
    }

    public void setPropertyNature(String propertyNature) {
        this.propertyNature = propertyNature;
    }

    public String getPropertyCertNo() {
        return propertyCertNo;
    }

    public void setPropertyCertNo(String propertyCertNo) {
        this.propertyCertNo = propertyCertNo;
    }

    public String getPropertyNo() {
        return propertyNo;
    }

    public void setPropertyNo(String propertyNo) {
        this.propertyNo = propertyNo;
    }

    public String getLandNo() {
        return landNo;
    }

    public void setLandNo(String landNo) {
        this.landNo = landNo;
    }

    public Integer getSortOrder() {
        return sortOrder;
    }

    public void setSortOrder(Integer sortOrder) {
        this.sortOrder = sortOrder;
    }

    public BigDecimal getBuildingArea() {
        return buildingArea;
    }

    public void setBuildingArea(BigDecimal buildingArea) {
        this.buildingArea = buildingArea;
    }

    public BigDecimal getPropertyArea() {
        return propertyArea;
    }

    public void setPropertyArea(BigDecimal propertyArea) {
        this.propertyArea = propertyArea;
    }

    public BigDecimal getRentableArea() {
        return rentableArea;
    }

    public void setRentableArea(BigDecimal rentableArea) {
        this.rentableArea = rentableArea;
    }

    public BigDecimal getSelfUseArea() {
        return selfUseArea;
    }

    public void setSelfUseArea(BigDecimal selfUseArea) {
        this.selfUseArea = selfUseArea;
    }

    public BigDecimal getSupportingArea() {
        return supportingArea;
    }

    public void setSupportingArea(BigDecimal supportingArea) {
        this.supportingArea = supportingArea;
    }

    public BigDecimal getParkingArea() {
        return parkingArea;
    }

    public void setParkingArea(BigDecimal parkingArea) {
        this.parkingArea = parkingArea;
    }

    public String getAccountId() {
        return accountId;
    }

    public void setAccountId(String accountId) {
        this.accountId = accountId;
    }

    public String getBuildingTags() {
        return buildingTags;
    }

    public void setBuildingTags(String buildingTags) {
        this.buildingTags = buildingTags;
    }

    public Integer getTotalRooms() {
        return totalRooms;
    }

    public void setTotalRooms(Integer totalRooms) {
        this.totalRooms = totalRooms;
    }

    public BigDecimal getRentalRate() {
        return rentalRate;
    }

    public void setRentalRate(BigDecimal rentalRate) {
        this.rentalRate = rentalRate;
    }

    public BigDecimal getRentedArea() {
        return rentedArea;
    }

    public void setRentedArea(BigDecimal rentedArea) {
        this.rentedArea = rentedArea;
    }

    public Integer getRentedContracts() {
        return rentedContracts;
    }

    public void setRentedContracts(Integer rentedContracts) {
        this.rentedContracts = rentedContracts;
    }

    public BigDecimal getWaitingArea() {
        return waitingArea;
    }

    public void setWaitingArea(BigDecimal waitingArea) {
        this.waitingArea = waitingArea;
    }

    public Integer getWaitingRooms() {
        return waitingRooms;
    }

    public void setWaitingRooms(Integer waitingRooms) {
        this.waitingRooms = waitingRooms;
    }

    public String getIsHot() {
        return isHot;
    }

    public void setIsHot(String isHot) {
        this.isHot = isHot;
    }

    public Integer getTotalFloors() {
        return totalFloors;
    }

    public void setTotalFloors(Integer totalFloors) {
        this.totalFloors = totalFloors;
    }

    public String getFacilities() {
        return facilities;
    }

    public void setFacilities(String facilities) {
        this.facilities = facilities;
    }

    public String getImageUrl() {
        return imageUrl;
    }

    public void setImageUrl(String imageUrl) {
        this.imageUrl = imageUrl;
    }

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
}