package com.eden.room.domain;

import lombok.Data;
import lombok.EqualsAndHashCode;
import javax.validation.constraints.NotBlank;
import javax.validation.constraints.NotNull;
import javax.validation.constraints.DecimalMin;
import javax.validation.constraints.Digits;
import java.math.BigDecimal;
import javax.persistence.Table;
import javax.persistence.Column;
import javax.persistence.Id;

/**
 * 项目信息实体类
 * 对应数据库表: TB_PROJECT
 */
@Data
@EqualsAndHashCode(callSuper = true)
@Table(name = "TB_PROJECT")
public class Project extends BaseEntity {
    private static final long serialVersionUID = 1L;

    /** 项目ID */
    @Id
    @Column(name = "id")
    @NotBlank(message = "项目ID不能为空")
    private String id;

    /** 租户ID */
    @Column(name = "tenant_id")
    private String tenantId;

    /** 
     * 项目类型：写字楼、产业园区、商场、联合办公、公寓、小区、社区养老
     */
    @Column(name = "project_type")
    @NotBlank(message = "项目类型不能为空")
    private String projectType;

    /** 项目名称 */
    @Column(name = "project_name")
    @NotBlank(message = "项目名称不能为空")
    private String projectName;

    /** 项目简称 */
    @Column(name = "project_short_name")
    private String projectShortName;

    /** 所属地区 */
    @Column(name = "region")
    private String region;

    /** 详细地址 */
    @Column(name = "address")
    private String address;

    /** 项目标签，枚举值 */
    @Column(name = "project_tags")
    private String projectTags;

    /** 项目简介 */
    @Column(name = "project_desc")
    private String projectDesc;

    /** 项目图片URL */
    @Column(name = "project_image")
    private String projectImage;

    /** 项目管理人员ID */
    @Column(name = "manager_id")
    private String managerId;

    // --- 以下为扩展统计字段，不在数据库表中 ---
    
    /** 管理面积(扩展字段) - 来源于属于项目的所有房源的建筑面积之和 */
    @DecimalMin(value = "0.01", message = "管理面积必须大于0")
    @Digits(integer = 10, fraction = 2, message = "管理面积最多支持10位整数和2位小数")
    private BigDecimal manageArea;

    /** 可招商面积(扩展字段) - 来源于所有招商状态为招商房源的建筑面积总和 */
    @DecimalMin(value = "0.01", message = "可招商面积必须大于0")
    @Digits(integer = 10, fraction = 2, message = "可招商面积最多支持10位整数和2位小数")
    private BigDecimal availableArea;

    /** 总房源数量(扩展字段) - 来源于属于项目的所有房源的数量统计 */
    @NotNull(message = "总房源数量不能为空")
    private Integer totalRooms;

    /** 可招商房源数量(扩展字段) - 来源于项目下所有楼宇的所有房源租赁状态为可招商的房源总数 */
    @NotNull(message = "可招商房源数量不能为空")
    private Integer availableRooms;

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getTenantId() {
        return tenantId;
    }

    public void setTenantId(String tenantId) {
        this.tenantId = tenantId;
    }

    public String getProjectType() {
        return projectType;
    }

    public void setProjectType(String projectType) {
        this.projectType = projectType;
    }

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

    public String getProjectShortName() {
        return projectShortName;
    }

    public void setProjectShortName(String projectShortName) {
        this.projectShortName = projectShortName;
    }

    public String getRegion() {
        return region;
    }

    public void setRegion(String region) {
        this.region = region;
    }

    public String getAddress() {
        return address;
    }

    public void setAddress(String address) {
        this.address = address;
    }

    public String getProjectTags() {
        return projectTags;
    }

    public void setProjectTags(String projectTags) {
        this.projectTags = projectTags;
    }

    public String getProjectDesc() {
        return projectDesc;
    }

    public void setProjectDesc(String projectDesc) {
        this.projectDesc = projectDesc;
    }

    public String getProjectImage() {
        return projectImage;
    }

    public void setProjectImage(String projectImage) {
        this.projectImage = projectImage;
    }

    public String getManagerId() {
        return managerId;
    }

    public void setManagerId(String managerId) {
        this.managerId = managerId;
    }

    public BigDecimal getManageArea() {
        return manageArea;
    }

    public void setManageArea(BigDecimal manageArea) {
        this.manageArea = manageArea;
    }

    public BigDecimal getAvailableArea() {
        return availableArea;
    }

    public void setAvailableArea(BigDecimal availableArea) {
        this.availableArea = availableArea;
    }

    public Integer getTotalRooms() {
        return totalRooms;
    }

    public void setTotalRooms(Integer totalRooms) {
        this.totalRooms = totalRooms;
    }

    public Integer getAvailableRooms() {
        return availableRooms;
    }

    public void setAvailableRooms(Integer availableRooms) {
        this.availableRooms = availableRooms;
    }
}