package com.eden.room.domain;

import java.math.BigDecimal;
import java.util.Date;

import com.eden.room.common.enums.PriceUnitEnum;
import com.fasterxml.jackson.annotation.JsonFormat;
import org.apache.commons.lang3.builder.ToStringBuilder;
import org.apache.commons.lang3.builder.ToStringStyle;
import com.eden.room.utils.excel.Excel;
import org.springframework.format.annotation.DateTimeFormat;


/**
 * 房源基本信息实体类 TB_ROOM
 * 
 * @author eden
 * @date 2023-08-01
 */
public class Room extends BaseEntity
{
    private static final long serialVersionUID = 1L;

    /** 主键ID */
    private Long id;

    /** 项目ID */
    @Excel(name = "项目ID")
    private String projectId;
    
    /** 项目名称 */
    @Excel(name = "项目名称")
    private String projectName;

    /** 楼宇ID */
    @Excel(name = "楼宇ID")
    private Long buildingId;
    
    /** 楼宇名称 */
    @Excel(name = "楼宇名称")
    private String buildingName;

    /** 楼层ID */
    @Excel(name = "楼层ID")
    private Long floorId;
    
    /** 楼层名称 */
    @Excel(name = "楼层名称")
    private String floorName;

    /** 房号 */
    @Excel(name = "房号")
    private String roomNumber;

    /** 房源数字编号 */
    @Excel(name = "房间数字编号")
    private String roomDigitalNumber;
    
    /** 房源管理编号 */
    @Excel(name = "房源管理编号")
    private String roomManageNumber;

    /** 房源名称 */
    @Excel(name = "房源名称")
    private String roomName;

    /** 房源类型 */
    @Excel(name = "房源类型", readConverterExp = "1=办公,2=商业,3=仓储,4=厂房,5=多经,6=公寓,7=住宅,8=其他")
    private String roomType;

    /** 楼层 */
    @Excel(name = "楼层")
    private String floor;

    /** 是否整层 */
    @Excel(name = "是否整层", readConverterExp = "0=否,1=是")
    private String isWholeFloor;

    /** 建筑面积 */
    @Excel(name = "建筑面积")
    private BigDecimal buildingArea;
    
    /** 计租面积 */
    @Excel(name = "计租面积")
    private BigDecimal rentalArea;
    
    /** 计费面积 */
    @Excel(name = "计费面积")
    private BigDecimal billingArea;
    
    /** 套内面积 */
    @Excel(name = "套内面积")
    private BigDecimal innerArea;
    
    /** 是否虚拟房源 */
    @Excel(name = "是否虚拟房源", readConverterExp = "0=否,1=是")
    private String isVirtual;
    
    /** 房源交付时间 */
    @JsonFormat(pattern = "yyyy-MM-dd")
    @Excel(name = "房源交付时间", width = 30, dateFormat = "yyyy-MM-dd")
    private Date deliveryTime;
    
    /** 绑定业主ID */
    @Excel(name = "绑定业主ID")
    private Long ownerId;
    
    /** 产权性质 */
    @Excel(name = "产权性质", readConverterExp = "1=自持,2=承租,3=自持+承租")
    private String propertyNature;
    
    /** 层高(米) */
    @Excel(name = "层高(米)")
    private BigDecimal height;
    
    /** 荷载值 */
    @Excel(name = "荷载值")
    private BigDecimal loadValue;
    
    /** 房源状态 */
    @Excel(name = "房源状态", readConverterExp = "1=公开,2=关闭,3=私密")
    private String roomStatus;

    /** 房源面积 */
    @Excel(name = "房源面积")
    private BigDecimal roomArea;
    /** 报价 */
    @Excel(name = "报价")
    private BigDecimal price;

    public String getPriceUnit() {
        return priceUnit;
    }

    public void setPriceUnit(String priceUnit) {
        this.priceUnit = priceUnit;
    }

    /** 报价单位 */
    @Excel(name = "priceUnit")
    private String priceUnit;

    public String getPrice() {
        return (price==null? "":price.toString()) + PriceUnitEnum.getValue(getPriceUnit());
    }

    public void setPrice(BigDecimal price) {
        this.price = price;
    }


    public String getBusinessStatus() {
        return businessStatus;
    }

    public void setBusinessStatus(String businessStatus) {
        this.businessStatus = businessStatus;
    }

    public String getDecorationStatus() {
        return decorationStatus;
    }

    public void setDecorationStatus(String decorationStatus) {
        this.decorationStatus = decorationStatus;
    }

    /** 租赁状态 */
    @Excel(name = "租赁状态")
    private String rentalStatus;
    /** 可租日期 */
    @JsonFormat(pattern = "yyyy-MM-dd")
    @DateTimeFormat(pattern = "yyyy-MM-dd")
    private Date availableDate;

    /** 出租状态 */
    @Excel(name = "招商状态", readConverterExp = "1=招商,2=不招商")
    private String businessStatus;
    /** 装修情况 */
    @Excel(name = "装修情况")
    private String decorationStatus;

    public void setId(Long id)
    {
        this.id = id;
    }

    public Long getId()
    {
        return id;
    }

    public void setProjectId(String projectId) 
    {
        this.projectId = projectId;
    }

    public String getProjectId() 
    {
        return projectId;
    }
    
    public void setProjectName(String projectName) 
    {
        this.projectName = projectName;
    }

    public String getProjectName() 
    {
        return projectName;
    }

    public void setBuildingId(Long buildingId)
    {
        this.buildingId = buildingId;
    }

    public Long getBuildingId()
    {
        return buildingId;
    }
    
    public void setBuildingName(String buildingName) 
    {
        this.buildingName = buildingName;
    }

    public String getBuildingName() 
    {
        return buildingName;
    }

    public void setFloorId(Long floorId)
    {
        this.floorId = floorId;
    }

    public Long getFloorId()
    {
        return floorId;
    }
    
    public void setFloorName(String floorName) 
    {
        this.floorName = floorName;
    }

    public String getFloorName() 
    {
        return floorName;
    }

    public void setRoomNumber(String roomNumber) 
    {
        this.roomNumber = roomNumber;
    }

    public String getRoomNumber() 
    {
        return roomNumber;
    }

    public void setRoomDigitalNumber(String roomDigitalNumber) 
    {
        this.roomDigitalNumber = roomDigitalNumber;
    }

    public String getRoomDigitalNumber() 
    {
        return roomDigitalNumber;
    }
    
    public void setRoomManageNumber(String roomManageNumber) 
    {
        this.roomManageNumber = roomManageNumber;
    }

    public String getRoomManageNumber() 
    {
        return roomManageNumber;
    }

    public void setRoomName(String roomName) 
    {
        this.roomName = roomName;
    }

    public String getRoomName() 
    {
        return roomName;
    }

    public void setRoomType(String roomType) 
    {
        this.roomType = roomType;
    }

    public String getRoomType() 
    {
        return roomType;
    }

    public void setFloor(String floor) 
    {
        this.floor = floor;
    }

    public String getFloor() 
    {
        return floor;
    }

    public void setIsWholeFloor(String isWholeFloor) 
    {
        this.isWholeFloor = isWholeFloor;
    }

    public String getIsWholeFloor() 
    {
        return isWholeFloor;
    }

    public void setBuildingArea(BigDecimal buildingArea)
    {
        this.buildingArea = buildingArea;
    }

    public BigDecimal getBuildingArea()
    {
        return buildingArea;
    }
    
    public void setRentalArea(BigDecimal rentalArea)
    {
        this.rentalArea = rentalArea;
    }

    public BigDecimal getRentalArea()
    {
        return rentalArea;
    }
    
    public void setBillingArea(BigDecimal billingArea)
    {
        this.billingArea = billingArea;
    }

    public BigDecimal getBillingArea()
    {
        return billingArea;
    }
    
    public void setInnerArea(BigDecimal innerArea)
    {
        this.innerArea = innerArea;
    }

    public BigDecimal getInnerArea()
    {
        return innerArea;
    }
    
    public void setIsVirtual(String isVirtual) 
    {
        this.isVirtual = isVirtual;
    }

    public String getIsVirtual() 
    {
        return isVirtual;
    }
    
    public void setDeliveryTime(Date deliveryTime) 
    {
        this.deliveryTime = deliveryTime;
    }

    public Date getDeliveryTime() 
    {
        return deliveryTime;
    }
    
    public void setOwnerId(Long ownerId)
    {
        this.ownerId = ownerId;
    }

    public Long getOwnerId()
    {
        return ownerId;
    }
    
    public void setPropertyNature(String propertyNature) 
    {
        this.propertyNature = propertyNature;
    }

    public String getPropertyNature() 
    {
        return propertyNature;
    }
    
    public void setHeight(BigDecimal height)
    {
        this.height = height;
    }

    public BigDecimal getHeight()
    {
        return height;
    }
    
    public void setLoadValue(BigDecimal loadValue)
    {
        this.loadValue = loadValue;
    }

    public BigDecimal getLoadValue()
    {
        return loadValue;
    }
    
    public void setRoomStatus(String roomStatus) 
    {
        this.roomStatus = roomStatus;
    }

    public String getRoomStatus() 
    {
        return roomStatus;
    }

    public void setRoomArea(BigDecimal roomArea)
    {
        this.roomArea = roomArea;
    }

    public BigDecimal getRoomArea()
    {
        return roomArea;
    }

    public void setRentalStatus(String rentalStatus) 
    {
        this.rentalStatus = rentalStatus;
    }

    public String getRentalStatus() 
    {
        return rentalStatus;
    }

    @Override
    public String toString() {
        return new ToStringBuilder(this,ToStringStyle.MULTI_LINE_STYLE)
            .append("id", getId())
            .append("tenantId", getTenantId())
            .append("projectId", getProjectId())
            .append("buildingId", getBuildingId())
            .append("floorId", getFloorId())
            .append("roomNumber", getRoomNumber())
            .append("roomDigitalNumber", getRoomDigitalNumber())
            .append("roomManageNumber", getRoomManageNumber())
            .append("buildingArea", getBuildingArea())
            .append("rentalArea", getRentalArea())
            .append("billingArea", getBillingArea())
            .append("innerArea", getInnerArea())
            .append("isVirtual", getIsVirtual())
            .append("deliveryTime", getDeliveryTime())
            .append("ownerId", getOwnerId())
            .append("propertyNature", getPropertyNature())
            .append("height", getHeight())
            .append("loadValue", getLoadValue())
            .append("roomStatus", getRoomStatus())
            .append("roomType", getRoomType())
            .append("createTime", getCreateTime())
            .append("lastModTime", getLastModTime())
            .append("createUserId", getCreateUserId())
            .append("lastModUserId", getLastModUserId())
            .append("delFlag", getDelFlag())
            .append("remark", getRemark())
            .toString();
    }
} 