package com.eden.room.domain;

import java.util.Date;
import java.math.BigDecimal;
import com.fasterxml.jackson.annotation.JsonFormat;
import lombok.Data;
import org.springframework.format.annotation.DateTimeFormat;

/**
 * 房源招商信息实体
 */
@Data
public class RoomBusinessInfo extends BaseEntity {
    /** 招商信息ID */
    private Long id;
    
    /** 租户ID */
    private String tenantId;
    
    /** 房源ID */
    private Long roomId;
    
    /** 租赁状态：待租，已租，下架 */
    private String rentalStatus;
    
    /** 招商状态: 招商，不招商 */
    private String businessStatus;
    
    /** 可租日期 */
    @JsonFormat(pattern = "yyyy-MM-dd")
    @DateTimeFormat(pattern = "yyyy-MM-dd")
    private Date availableDate;
    
    /** 装修情况：精装，简装，毛坯，标准交付，豪装 */
    private String decorationStatus;
    
    /** 报价 */
    private BigDecimal price;
    
    /** 报价单位 */
    private String priceUnit;
    
    /** 底价 */
    private BigDecimal floorPrice;
    
    /** 底价单位 */
    private String floorPriceUnit;
    
    /** 房源招商编号 */
    private String businessNumber;
    
    /** 招商条件 */
    private String businessCondition;
    
    /** 创建时间 */
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    private Date createTime;
    
    /** 更新时间 */
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    private Date updateTime;
    
    /** 创建人 */
    private String createBy;
    
    /** 更新人 */
    private String updateBy;
    
    /** 是否删除：0-否，1-是 */
    private String delFlag;
    
    /** 备注 */
    private String remark;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getTenantId() {
        return tenantId;
    }

    public void setTenantId(String tenantId) {
        this.tenantId = tenantId;
    }

    public Long getRoomId() {
        return roomId;
    }

    public void setRoomId(Long roomId) {
        this.roomId = roomId;
    }

    public String getRentalStatus() {
        return rentalStatus;
    }

    public void setRentalStatus(String rentalStatus) {
        this.rentalStatus = rentalStatus;
    }

    public String getBusinessStatus() {
        return businessStatus;
    }

    public void setBusinessStatus(String businessStatus) {
        this.businessStatus = businessStatus;
    }

    public Date getAvailableDate() {
        return availableDate;
    }

    public void setAvailableDate(Date availableDate) {
        this.availableDate = availableDate;
    }

    public String getDecorationStatus() {
        return decorationStatus;
    }

    public void setDecorationStatus(String decorationStatus) {
        this.decorationStatus = decorationStatus;
    }

    public BigDecimal getPrice() {
        return price;
    }

    public void setPrice(BigDecimal price) {
        this.price = price;
    }

    public String getPriceUnit() {
        return priceUnit;
    }

    public void setPriceUnit(String priceUnit) {
        this.priceUnit = priceUnit;
    }

    public BigDecimal getFloorPrice() {
        return floorPrice;
    }

    public void setFloorPrice(BigDecimal floorPrice) {
        this.floorPrice = floorPrice;
    }

    public String getFloorPriceUnit() {
        return floorPriceUnit;
    }

    public void setFloorPriceUnit(String floorPriceUnit) {
        this.floorPriceUnit = floorPriceUnit;
    }

    public String getBusinessNumber() {
        return businessNumber;
    }

    public void setBusinessNumber(String businessNumber) {
        this.businessNumber = businessNumber;
    }

    public String getBusinessCondition() {
        return businessCondition;
    }

    public void setBusinessCondition(String businessCondition) {
        this.businessCondition = businessCondition;
    }

    public Date getCreateTime() {
        return createTime;
    }

    public void setCreateTime(Date createTime) {
        this.createTime = createTime;
    }

    public Date getUpdateTime() {
        return updateTime;
    }

    public void setUpdateTime(Date updateTime) {
        this.updateTime = updateTime;
    }

    public String getCreateBy() {
        return createBy;
    }

    public void setCreateBy(String createBy) {
        this.createBy = createBy;
    }

    public String getUpdateBy() {
        return updateBy;
    }

    public void setUpdateBy(String updateBy) {
        this.updateBy = updateBy;
    }

    public String getDelFlag() {
        return delFlag;
    }

    public void setDelFlag(String delFlag) {
        this.delFlag = delFlag;
    }

    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }

    @Override
    public String toString() {
        return "RoomBusinessInfo [id=" + id + ", tenantId=" + tenantId + ", roomId=" + roomId + ", rentalStatus="
                + rentalStatus + ", businessStatus=" + businessStatus + ", availableDate=" + availableDate
                + ", decorationStatus=" + decorationStatus + ", price=" + price + ", priceUnit=" + priceUnit
                + ", floorPrice=" + floorPrice + ", floorPriceUnit=" + floorPriceUnit + ", businessNumber="
                + businessNumber + ", businessCondition=" + businessCondition + ", createTime=" + createTime
                + ", updateTime=" + updateTime + ", delFlag=" + delFlag + ", remark=" + remark + "]";
    }
} 