package com.eden.room.domain.dto;

import com.eden.room.utils.excel.Excel;
import lombok.Data;

import java.io.Serializable;
import java.math.BigDecimal;

/**
 * 房源导入DTO
 */
@Data
public class RoomImportDTO implements Serializable {

    private static final long serialVersionUID = 1L;

    /** 项目 */
    @Excel(name = "项目", sort = 1, required = true,cellType = Excel.ColumnType.STRING)
    private String projectName;

    /** 楼宇 */
    @Excel(name = "楼宇", sort = 2, required = true,cellType = Excel.ColumnType.STRING)
    private String buildingName;

    /** 楼层 */
    @Excel(name = "楼层", sort = 3, required = true,cellType = Excel.ColumnType.STRING)
    private String floorName;

    /** 房号 */
    @Excel(name = "房号", sort = 4, required = true,cellType = Excel.ColumnType.STRING)
    private String roomNumber;

    /** 房间数字编号 */
    @Excel(name = "房间数字编号", sort = 5, required = true,cellType = Excel.ColumnType.STRING)
    private String roomDigitalNumber;

    /** 计租面积 */
    @Excel(name = "计租面积（m²）", sort = 6, suffix = "㎡", cellType = Excel.ColumnType.NUMERIC)
    private BigDecimal rentalArea;

    /** 计费面积 */
    @Excel(name = "计费面积（m²）", sort = 7, suffix = "㎡", cellType = Excel.ColumnType.NUMERIC)
    private BigDecimal billingArea;

    /** 建筑面积 */
    @Excel(name = "建筑面积", sort = 8, suffix = "㎡", cellType = Excel.ColumnType.NUMERIC)
    private BigDecimal buildingArea;

    /** 层高 */
    @Excel(name = "层高（m）", sort = 9, suffix = "m", cellType = Excel.ColumnType.NUMERIC)
    private BigDecimal height;

    /** 报价 */
    @Excel(name = "报价", sort = 10, cellType = Excel.ColumnType.NUMERIC)
    private BigDecimal price;

    /** 底价 */
    @Excel(name = "底价", sort = 11, cellType = Excel.ColumnType.NUMERIC)
    private BigDecimal floorPrice;

    /** 单位 */
    @Excel(name = "单位", sort = 12,cellType = Excel.ColumnType.STRING)
    private String priceUnit;

    /** 房源备案号 */
    @Excel(name = "房源备案号", sort = 13, cellType = Excel.ColumnType.STRING)
    private String roomRecordNumber;

    /** 标签 */
    @Excel(name = "标签", sort = 14,cellType = Excel.ColumnType.STRING)
    private String tags;

    /** 房源管理编号 */
    @Excel(name = "房源管理编号", sort = 15,cellType = Excel.ColumnType.STRING)
    private String roomManageNumber;

    /** 导入结果说明 */
    @Excel(name = "导入结果说明", sort = 16,cellType = Excel.ColumnType.STRING)
    private String importResult;


    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

    public String getBuildingName() {
        return buildingName;
    }

    public void setBuildingName(String buildingName) {
        this.buildingName = buildingName;
    }

    public String getFloorName() {
        return floorName;
    }

    public void setFloorName(String floorName) {
        this.floorName = floorName;
    }

    public String getRoomNumber() {
        return roomNumber;
    }

    public void setRoomNumber(String roomNumber) {
        this.roomNumber = roomNumber;
    }

    public String getRoomDigitalNumber() {
        return roomDigitalNumber;
    }

    public void setRoomDigitalNumber(String roomDigitalNumber) {
        this.roomDigitalNumber = roomDigitalNumber;
    }

    public BigDecimal getRentalArea() {
        return rentalArea;
    }

    public void setRentalArea(BigDecimal rentalArea) {
        this.rentalArea = rentalArea;
    }

    public BigDecimal getBillingArea() {
        return billingArea;
    }

    public void setBillingArea(BigDecimal billingArea) {
        this.billingArea = billingArea;
    }

    public BigDecimal getBuildingArea() {
        return buildingArea;
    }

    public void setBuildingArea(BigDecimal buildingArea) {
        this.buildingArea = buildingArea;
    }

    public BigDecimal getHeight() {
        return height;
    }

    public void setHeight(BigDecimal height) {
        this.height = height;
    }

    public BigDecimal getPrice() {
        return price;
    }

    public void setPrice(BigDecimal price) {
        this.price = price;
    }

    public BigDecimal getFloorPrice() {
        return floorPrice;
    }

    public void setFloorPrice(BigDecimal floorPrice) {
        this.floorPrice = floorPrice;
    }

    public String getPriceUnit() {
        return priceUnit;
    }

    public void setPriceUnit(String priceUnit) {
        this.priceUnit = priceUnit;
    }

    public String getRoomRecordNumber() {
        return roomRecordNumber;
    }

    public void setRoomRecordNumber(String roomRecordNumber) {
        this.roomRecordNumber = roomRecordNumber;
    }

    public String getTags() {
        return tags;
    }

    public void setTags(String tags) {
        this.tags = tags;
    }

    public String getRoomManageNumber() {
        return roomManageNumber;
    }

    public void setRoomManageNumber(String roomManageNumber) {
        this.roomManageNumber = roomManageNumber;
    }

    public String getImportResult() {
        return importResult;
    }

    public void setImportResult(String importResult) {
        this.importResult = importResult;
    }

}