package com.eden.room.feign;

import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestParam;

import com.eden.room.common.Result;

/**
 * 合同服务远程调用客户端
 */
@FeignClient(name = "eden-contract-service", fallback = ContractFeignFallback.class)
public interface ContractFeignClient {
    /**
     * 查询房源关联的执行中合同数量
     * 
     * @param roomId 房源ID
     * @param buildingId 楼宇ID
     * @return 合同数量
     */
    @GetMapping("/contract/countByRoomId")
    Result<Integer> countContractsByRoomId(@RequestParam("roomId") Long roomId, @RequestParam("buildingId") Long buildingId);

    /**
     * 检查房源是否有正在执行的合同
     *
     * @param roomId 房源ID
     * @param buildingId 楼宇ID
     * @return 是否有正在执行的合同
     */
    @GetMapping("/contract/api/checkRoomContract")
    boolean checkRoomContract(@RequestParam("roomId") Long roomId, @RequestParam(value = "buildingId", required = false) Long buildingId);
} 