package com.eden.room.feign;

import com.eden.room.domain.dto.OwnerDTO;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestParam;

import java.util.List;

/**
 * 业户服务远程调用客户端
 */
@FeignClient(name = "eden-customer-service", fallback = CustomerFeignFallback.class)
public interface CustomerFeignClient {

    /**
     * 根据ID获取业主信息
     *
     * @param id 业主ID
     * @return 业主信息
     */
    @GetMapping("/customer/owner/api/getById")
    OwnerDTO getOwnerById(@RequestParam("id") Long id);

    /**
     * 获取所有业主列表
     *
     * @return 业主列表
     */
    @GetMapping("/customer/owner/api/list")
    List<OwnerDTO> getOwnerList();

    /**
     * 根据名称查询业主
     *
     * @param name 业主名称
     * @return 业主列表
     */
    @GetMapping("/customer/owner/api/getByName")
    List<OwnerDTO> getOwnerByName(@RequestParam("name") String name);
} 