package com.eden.room.feign;

import java.util.List;

import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestParam;

import com.eden.room.common.Result;
import com.eden.room.domain.dto.OwnerDTO;

/**
 * 业主信息远程调用接口
 */
@FeignClient(name = "customer-service", path = "/customer")
public interface OwnerFeignClient {
    
    /**
     * 获取全部业主列表
     * 
     * @return 业主列表
     */
    @GetMapping("/owner/list")
    Result<List<OwnerDTO>> listOwners();
    
    /**
     * 根据姓名查询业主列表
     * 
     * @param name 业主姓名
     * @return 业主列表
     */
    @GetMapping("/owner/search")
    Result<List<OwnerDTO>> searchOwnersByName(@RequestParam("name") String name);
} 