package com.eden.room.feign;

import com.eden.room.domain.dto.TagDTO;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestParam;

import java.util.List;

/**
 * 标签服务远程调用客户端
 */
@FeignClient(name = "eden-tag-service", fallback = TagFeignFallback.class)
public interface TagFeignClient {

    /**
     * 获取所有房源标签
     *
     * @return 标签列表
     */
    @GetMapping("/tag/room/api/list")
    List<TagDTO> getAllRoomTags();

    /**
     * 根据ID数组获取标签
     *
     * @param ids 标签ID数组
     * @return 标签列表
     */
    @GetMapping("/tag/room/api/getByIds")
    List<TagDTO> getTagsByIds(@RequestParam("ids") String[] ids);
} 