package com.eden.room.mapper;

import java.util.List;
import com.eden.room.domain.Building;

/**
 * 楼宇信息数据访问层
 */
public interface BuildingMapper {
    /**
     * 查询楼宇信息列表
     * 
     * @param building 楼宇信息查询条件
     * @return 楼宇信息集合
     */
    List<Building> selectBuildingList(Building building);
    
    /**
     * 根据楼宇ID查询楼宇信息
     * 
     * @param id 楼宇ID
     * @return 楼宇信息
     */
    Building selectBuildingById(Long id);
    
    /**
     * 新增楼宇信息
     * 
     * @param building 楼宇信息
     * @return 结果
     */
    int insertBuilding(Building building);
    
    /**
     * 修改楼宇信息
     * 
     * @param building 楼宇信息
     * @return 结果
     */
    int updateBuilding(Building building);
    
    /**
     * 批量删除楼宇信息
     * 
     * @param ids 需要删除的楼宇ID数组
     * @return 结果
     */
    int deleteBuildingByIds(String[] ids);
    
    /**
     * 删除楼宇信息
     * 
     * @param id 楼宇ID
     * @return 结果
     */
    int deleteBuildingById(Long id);
    
    /**
     * 检查楼宇名称是否已存在
     * 
     * @param building 楼宇信息
     * @return 结果
     */
    int checkBuildingNameExists(Building building);
    
    /**
     * 检查楼宇编号是否已存在
     * 
     * @param building 楼宇信息
     * @return 结果
     */
    int checkBuildingCodeExists(Building building);
    
    /**
     * 楼宇统计信息
     * 
     * @param id 楼宇ID
     * @return 楼宇信息
     */
    Building selectBuildingStatistics(Long id);
    
    /**
     * 根据楼宇名称和项目ID查询楼宇ID
     * 
     * @param buildingName 楼宇名称
     * @param projectId 项目ID
     * @return 楼宇ID
     */
    String selectBuildingIdByNameAndProjectId(String buildingName, String projectId);
    
    /**
     * 检查楼宇是否有楼层
     * 
     * @param id 楼宇ID
     * @return 结果
     */
    boolean checkBuildingHasFloors(Long id);

    List<Building> getBuildByIds(List<String> ids);
} 