package com.eden.room.mapper;

import com.eden.room.domain.RoomExtendInfo;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * 房源拓展信息数据访问层
 */
@Mapper
public interface RoomExtendInfoMapper {
    
    /**
     * 查询房源拓展信息列表
     *
     * @param extendInfo 房源拓展信息
     * @return 房源拓展信息列表
     */
    List<RoomExtendInfo> selectRoomExtendInfoList(RoomExtendInfo extendInfo);
    
    /**
     * 根据ID查询房源拓展信息
     *
     * @param id 拓展信息ID
     * @return 房源拓展信息
     */
    RoomExtendInfo selectRoomExtendInfoById(@Param("id") String id);
    
    /**
     * 根据房源ID查询拓展信息
     *
     * @param roomId 房源ID
     * @return 房源拓展信息
     */
    RoomExtendInfo selectRoomExtendInfoByRoomId(@Param("roomId") Long roomId);
    
    /**
     * 新增房源拓展信息
     *
     * @param extendInfo 房源拓展信息
     * @return 结果
     */
    int insertRoomExtendInfo(RoomExtendInfo extendInfo);
    
    /**
     * 修改房源拓展信息
     *
     * @param extendInfo 房源拓展信息
     * @return 结果
     */
    int updateRoomExtendInfo(RoomExtendInfo extendInfo);
    
    /**
     * 删除房源拓展信息
     *
     * @param id 拓展信息ID
     * @return 结果
     */
    int deleteRoomExtendInfoById(@Param("id") String id);
    
    /**
     * 根据房源ID删除拓展信息
     *
     * @param roomId 房源ID
     * @return 结果
     */
    int deleteRoomExtendInfoByRoomId(@Param("roomId") Long roomId);
    
    /**
     * 批量删除房源拓展信息
     *
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    int deleteRoomExtendInfoByIds(@Param("ids") String[] ids);
    
    /**
     * 批量删除房源拓展信息（根据房源ID）
     *
     * @param roomIds 房源ID数组
     * @return 结果
     */
    int deleteRoomExtendInfoByRoomIds(@Param("roomIds") String[] roomIds);
} 