package com.eden.room.mapper;

import com.eden.room.domain.RoomImage;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * 房源图片数据访问层
 */
@Mapper
public interface RoomImageMapper {
    
    /**
     * 查询房源图片列表
     *
     * @param image 房源图片
     * @return 房源图片列表
     */
    List<RoomImage> selectRoomImageList(RoomImage image);
    
    /**
     * 根据ID查询房源图片
     *
     * @param id 图片ID
     * @return 房源图片
     */
    RoomImage selectRoomImageById(@Param("id") Long id);
    
    /**
     * 根据房源ID查询图片
     *
     * @param roomId 房源ID
     * @return 房源图片列表
     */
    List<RoomImage> selectRoomImagesByRoomId(@Param("roomId") Long roomId);
    
    /**
     * 根据房源ID和图片类型查询图片
     *
     * @param roomId 房源ID
     * @param imageType 图片类型
     * @return 房源图片列表
     */
    List<RoomImage> selectRoomImagesByRoomIdAndType(@Param("roomId") Long roomId, @Param("imageType") String imageType);
    
    /**
     * 新增房源图片
     *
     * @param image 房源图片
     * @return 结果
     */
    int insertRoomImage(RoomImage image);
    
    /**
     * 修改房源图片
     *
     * @param image 房源图片
     * @return 结果
     */
    int updateRoomImage(RoomImage image);
    
    /**
     * 删除房源图片
     *
     * @param id 图片ID
     * @return 结果
     */
    int deleteRoomImageById(@Param("id") Long id);
    
    /**
     * 根据房源ID删除图片
     *
     * @param roomId 房源ID
     * @return 结果
     */
    int deleteRoomImagesByRoomId(@Param("roomId") Long roomId);
    
    /**
     * 批量删除房源图片
     *
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    int deleteRoomImageByIds(@Param("ids") String[] ids);
    
    /**
     * 批量删除房源图片（根据房源ID）
     *
     * @param roomIds 房源ID数组
     * @return 结果
     */
    int deleteRoomImagesByRoomIds(@Param("roomIds") String[] roomIds);
} 