package com.eden.room.mapper;

import java.util.List;
import org.apache.ibatis.annotations.Param;
import com.eden.room.domain.Room;
import org.apache.ibatis.annotations.Mapper;

/**
 * 房源数据访问层
 */
@Mapper
public interface RoomMapper {
    /**
     * 查询房源列表
     *
     * @param room 房源信息
     * @return 房源列表
     */
    List<Room> selectRoomList(Room room);
    
    /**
     * 根据ID查询房源
     *
     * @param id 房源ID
     * @return 房源信息
     */
    Room selectRoomById(@Param("id") Long id);
    
    /**
     * 新增房源
     *
     * @param room 房源信息
     * @return 结果
     */
    int insertRoom(Room room);
    
    /**
     * 修改房源
     *
     * @param room 房源信息
     * @return 结果
     */
    int updateRoom(Room room);
    
    /**
     * 删除房源
     *
     * @param id 房源ID
     * @return 结果
     */
    int deleteRoomById(@Param("id") Long id);
    
    /**
     * 批量删除房源
     *
     * @param ids 房源ID数组
     * @return 结果
     */
    int deleteRoomByIds(@Param("ids") String[] ids);
    
    /**
     * 检查房号是否已存在
     *
     * @param roomNumber 房号
     * @param projectId 项目ID
     * @param buildingId 楼宇ID
     * @param floorId 楼层ID
     * @return 是否存在
     */
    boolean checkRoomNumberExist(@Param("roomNumber") String roomNumber, 
                               @Param("projectId") String projectId, 
                               @Param("buildingId") String buildingId, 
                               @Param("floorId") String floorId);
    
    /**
     * 检查房间数字编号是否已存在
     *
     * @param roomDigitalNumber 房间数字编号
     * @param projectId 项目ID
     * @param buildingId 楼宇ID
     * @param floorId 楼层ID
     * @return 是否存在
     */
    boolean checkRoomDigitalNumberExist(@Param("roomDigitalNumber") String roomDigitalNumber, 
                                      @Param("projectId") String projectId, 
                                      @Param("buildingId") String buildingId, 
                                      @Param("floorId") String floorId);
    
    /**
     * 根据ID数组查询房源列表
     *
     * @param ids 房源ID数组
     * @return 房源列表
     */
    List<Room> selectRoomByIds(@Param("ids") String[] ids);
} 