package com.eden.room.service;

import java.util.List;
import com.eden.room.domain.Building;
import com.eden.room.domain.Project;

/**
 * 楼宇信息服务接口
 */
public interface IBuildingService {
    /**
     * 查询楼宇信息列表
     * 
     * @param building 楼宇信息查询条件
     * @return 楼宇信息集合
     */
    List<Building> selectBuildingList(Building building);
    
    /**
     * 根据楼宇ID查询楼宇信息
     * 
     * @param id 楼宇ID
     * @return 楼宇信息
     */
    Building selectBuildingById(Long id);
    
    /**
     * 新增楼宇信息
     * 
     * @param building 楼宇信息
     * @return 结果
     */
    int insertBuilding(Building building);
    
    /**
     * 修改楼宇信息
     * 
     * @param building 楼宇信息
     * @return 结果
     */
    int updateBuilding(Building building);
    
    /**
     * 批量删除楼宇信息
     * 
     * @param ids 需要删除的楼宇ID数组
     * @return 结果
     */
    int deleteBuildingByIds(String[] ids);
    
    /**
     * 删除楼宇信息
     * 
     * @param id 楼宇ID
     * @return 结果
     */
    int deleteBuildingById(Long id);
    
    /**
     * 楼宇统计信息
     * 
     * @param id 楼宇ID
     * @return 楼宇信息
     */
    Building selectBuildingStatistics(Long id);

    boolean checkBuildingNameExists(Building building);

    List<Building> getBuildByIds(List<String> ids);
} 