package com.eden.room.service;

import java.util.List;
import com.eden.room.domain.Floor;

/**
 * 楼层信息服务接口
 */
public interface IFloorService {
    /**
     * 查询楼层信息列表
     * 
     * @param floor 楼层信息查询条件
     * @return 楼层信息集合
     */
    List<Floor> selectFloorList(Floor floor);
    
    /**
     * 根据楼层ID查询楼层信息
     * 
     * @param id 楼层ID
     * @return 楼层信息
     */
    Floor selectFloorById(Long id);
    
    /**
     * 新增楼层信息
     * 
     * @param floor 楼层信息
     * @return 结果
     */
    int insertFloor(Floor floor);
    
    /**
     * 修改楼层信息
     * 
     * @param floor 楼层信息
     * @return 结果
     */
    int updateFloor(Floor floor);
    
    /**
     * 批量删除楼层信息
     * 
     * @param ids 需要删除的楼层ID数组
     * @return 结果
     */
    int deleteFloorByIds(String[] ids);
    
    /**
     * 删除楼层信息
     * 
     * @param id 楼层ID
     * @return 结果
     */
    int deleteFloorById(Long id);
    
    /**
     * 根据楼宇ID查询楼层列表
     * 
     * @param buildingId 楼宇ID
     * @return 楼层列表
     */
    List<Floor> selectFloorListByBuildingId(Long buildingId);
} 