package com.eden.room.service;

import java.util.List;
import com.eden.room.domain.Project;

/**
 * 项目信息Service接口
 */
public interface IProjectService {
    /**
     * 查询项目信息
     * 
     * @param id 项目ID
     * @return 项目信息
     */
    public Project selectProjectById(String id);

    /**
     * 查询项目信息列表
     * 
     * @param project 项目信息
     * @return 项目信息集合
     */
    public List<Project> selectProjectList(Project project);

    /**
     * 新增项目信息
     * 
     * @param project 项目信息
     * @return 结果
     */
    public int insertProject(Project project);

    /**
     * 修改项目信息
     * 
     * @param project 项目信息
     * @return 结果
     */
    public int updateProject(Project project);

    /**
     * 批量删除项目信息
     * 
     * @param ids 需要删除的项目ID
     * @return 结果
     */
    public int deleteProjectByIds(String[] ids);

    /**
     * 删除项目信息信息
     * 
     * @param id 项目ID
     * @return 结果
     */
    public int deleteProjectById(String id);

    /**
     * 获取项目统计信息
     * 
     * @param id 项目ID
     * @return 项目统计信息
     */
    public Project selectProjectStatistics(String id);
    
    /**
     * 检查项目名称是否存在
     * 
     * @param project 项目信息
     * @return 结果
     */
    public boolean checkProjectNameExists(Project project);

    List<Project> selectProjectListByIds(List<String> ids);

    List<Project> selectProjectListByName(String name);
}