package com.eden.room.service;

import com.eden.room.domain.Room;
import com.eden.room.domain.RoomBusinessInfo;
import com.eden.room.domain.RoomExtendInfo;
import com.eden.room.domain.RoomImage;
import com.eden.room.domain.dto.RoomDTO;
import com.eden.room.domain.dto.RoomExportDTO;
import org.springframework.web.multipart.MultipartFile;

import java.util.List;
import java.util.Map;

/**
 * 房源服务接口
 */
public interface IRoomService {
    
    /**
     * 查询房源列表
     *
     * @param room 房源信息
     * @return 房源列表
     */
    List<Room> selectRoomList(Room room);
    
    /**
     * 根据ID查询房源
     *
     * @param id 房源ID
     * @return 房源信息
     */
    Room selectRoomById(Long id);
    
    /**
     * 查询房源详情（包括基础信息、招商信息、扩展信息）
     *
     * @param id 房源ID
     * @return 房源详情
     */
    RoomDTO selectRoomDetailById(Long id);
    
    /**
     * 新增房源信息
     *
     * @param roomDTO 房源信息DTO
     * @return 结果
     */
    int insertRoom(RoomDTO roomDTO);
    
    /**
     * 修改房源信息
     *
     * @param roomDTO 房源信息DTO
     * @return 结果
     */
    int updateRoom(RoomDTO roomDTO);
    
    /**
     * 删除房源信息
     *
     * @param id 房源ID
     * @return 结果
     */
    int deleteRoomById(Long id);
    
    /**
     * 批量删除房源信息
     *
     * @param ids 房源ID数组
     * @return 结果
     */
    int deleteRoomByIds(String[] ids);
    

    
    /**
     * 导出房源信息
     *
     * @param room 查询条件
     * @return 房源信息列表
     */
    List<RoomExportDTO> exportRoom(Room room);
    
    /**
     * 修改房源租赁状态
     *
     * @param id 房源ID
     * @param rentalStatus 租赁状态
     * @return 结果
     */
    int updateRoomRentalStatus(Long id, String rentalStatus);
    
    /**
     * 检查房源是否有正在执行的合同
     *
     * @param id 房源ID
     * @return 是否有正在执行的合同
     */
    boolean checkRoomContract(Long id);

    /**
     * 根据ID列表导出房源信息
     *
     * @param ids 房源ID数组
     * @return 房源信息列表
     */
    List<RoomExportDTO> exportRoomByIds(String[] ids);
    
    /**
     * 批量导入房源信息
     *
     * @param file 导入文件
     * @return 导入结果
     */
    Map<String, Object> importRoom(MultipartFile file) throws Exception;
} 