package com.eden.room.service;

import com.eden.room.common.enums.BusinessStatusEnum;
import com.eden.room.common.enums.DecorationStatusEnum;
import com.eden.room.common.enums.PriceUnitEnum;
import com.eden.room.common.enums.RentalStatusEnum;
import com.eden.room.domain.RoomExport;
import com.eden.room.domain.dto.RoomExportDTO;
import org.springframework.stereotype.Service;
import java.util.ArrayList;
import java.util.List;

/**
 * 房源模板服务
 */
@Service
public class RoomTemplateService {
    /**
     * 将房源导出DTO数据转换为房源导入模板格式
     * 
     * @param roomList 房源数据列表
     * @return 转换后的数据列表
     */
    public List<RoomExport> convertToRoomImportList(List<RoomExportDTO> roomList) {
        List<RoomExport> result = new ArrayList<>();
        
        if (roomList == null || roomList.isEmpty()) {
            return result;
        }
        
        for (RoomExportDTO roomDTO : roomList) {
            RoomExport roomExport = new RoomExport();
            
            // 设置基本信息
            roomExport.setProjectName(roomDTO.getProjectName());
            roomExport.setBuildingName(roomDTO.getBuildingName());
            roomExport.setFloorName(roomDTO.getFloorName());
            roomExport.setRoomNumber(roomDTO.getRoomNumber()); // 使用管理编号作为房源编号
            roomExport.setRentalArea(roomDTO.getRentalArea());
            roomExport.setPriceAndUnit((roomDTO.getPrice()==null?"":roomDTO.getPrice().toString()) + PriceUnitEnum.getValue(roomDTO.getPriceUnit()));
            roomExport.setRentalStatus(RentalStatusEnum.getValue(roomDTO.getRentalStatus()));
            roomExport.setAvailableDate(roomDTO.getAvailableDate());
            //TODO 根据tags 调接口去查对应的tagName
            roomExport.setTags(roomDTO.getTags());
            roomExport.setIsVirtual("1".equals(roomDTO.getIsVirtual())? "是":"否");
            roomExport.setBusinessStatus(BusinessStatusEnum.getValue(roomDTO.getBusinessStatus()));
            roomExport.setDecorationStatus(DecorationStatusEnum.getValue(roomDTO.getDecorationStatus()));
            roomExport.setDeliveryTime(roomDTO.getDeliveryTime());
            roomExport.setCreateTime(roomDTO.getCreateTime());
            result.add(roomExport);
        }
        
        return result;
    }


} 