package com.eden.room.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import com.eden.room.domain.Floor;
import com.eden.room.mapper.FloorMapper;
import com.eden.room.service.IFloorService;
import com.eden.common.utils.SecurityUtils;
import com.eden.common.exception.ServiceException;

/**
 * 楼层信息服务实现类
 */
@Service
public class FloorServiceImpl implements IFloorService {
    @Autowired
    private FloorMapper floorMapper;

    /**
     * 查询楼层信息列表
     */
    @Override
    public List<Floor> selectFloorList(Floor floor) {
        // 设置租户ID
        return floorMapper.selectFloorList(floor);
    }

    /**
     * 根据楼层ID查询楼层信息
     */
    @Override
    public Floor selectFloorById(Long id) {
        return floorMapper.selectFloorById(id);
    }

    /**
     * 新增楼层信息
     */
    @Override
    @Transactional
    public int insertFloor(Floor floor) {

        
//        // 检查楼层名称是否已存在
//        if (floorMapper.checkFloorNameExists(floor) > 0) {
//            throw new ServiceException("楼层名称已存在");
//        }
//
//        // 检查楼层数字编号是否已存在
//        if (floorMapper.checkFloorNumberExists(floor) > 0) {
//            throw new ServiceException("楼层数字编号已存在");
//        }
        
        return floorMapper.insertFloor(floor);
    }

    /**
     * 修改楼层信息
     */
    @Override
    @Transactional
    public int updateFloor(Floor floor) {

//        // 检查楼层名称是否已存在
//        if (floorMapper.checkFloorNameExists(floor) >= 1) {
//            throw new ServiceException("楼层名称已存在");
//        }
//
//        // 检查楼层数字编号是否已存在
//        if (floorMapper.checkFloorNumberExists(floor) >= 1) {
//            throw new ServiceException("楼层数字编号已存在");
//        }
        
        return floorMapper.updateFloor(floor);
    }

    /**
     * 批量删除楼层信息
     */
    @Override
    @Transactional
    public int deleteFloorByIds(String[] ids) {
        for (String id : ids) {
            // 检查楼层是否有关联的房源
            if (floorMapper.checkFloorHasRooms(Long.valueOf(id)) > 0) {
                Floor floor = floorMapper.selectFloorById(Long.valueOf(id));
                throw new ServiceException(String.format("楼层'%s'已分配房源，不能删除", floor.getFloorName()));
            }
        }
        return floorMapper.deleteFloorByIds(ids);
    }

    /**
     * 删除楼层信息
     */
    @Override
    @Transactional
    public int deleteFloorById(Long id) {
        // 检查楼层是否有关联的房源
        if (floorMapper.checkFloorHasRooms(id) > 0) {
            Floor floor = floorMapper.selectFloorById(id);
            throw new ServiceException(String.format("楼层'%s'已分配房源，不能删除", floor.getFloorName()));
        }
        return floorMapper.deleteFloorById(id);
    }

    /**
     * 根据楼宇ID查询楼层列表
     */
    @Override
    public List<Floor> selectFloorListByBuildingId(Long buildingId) {
        Floor floor = new Floor();
        floor.setBuildingId(buildingId);
        return floorMapper.selectFloorList(floor);
    }
} 