package com.eden.room.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.eden.room.mapper.ProjectMapper;
import com.eden.room.domain.Project;
import com.eden.room.service.IProjectService;

/**
 * 项目信息Service业务层处理
 */
@Service
public class ProjectServiceImpl implements IProjectService {
    @Autowired
    private ProjectMapper projectMapper;

    /**
     * 查询项目信息
     * 
     * @param id 项目ID
     * @return 项目信息
     */
    @Override
    public Project selectProjectById(String id) {
        return projectMapper.selectProjectById(id);
    }

    /**
     * 查询项目信息列表
     * 
     * @param project 项目信息
     * @return 项目信息
     */
    @Override
    public List<Project> selectProjectList(Project project) {
        return projectMapper.selectProjectList(project);
    }

    /**
     * 新增项目信息
     * 
     * @param project 项目信息
     * @return 结果
     */
    @Override
    public int insertProject(Project project) {
        return projectMapper.insertProject(project);
    }

    /**
     * 修改项目信息
     * 
     * @param project 项目信息
     * @return 结果
     */
    @Override
    public int updateProject(Project project) {
        return projectMapper.updateProject(project);
    }

    /**
     * 批量删除项目信息
     * 
     * @param ids 需要删除的项目ID
     * @return 结果
     */
    @Override
    public int deleteProjectByIds(String[] ids) {
        return projectMapper.deleteProjectByIds(ids);
    }

    /**
     * 删除项目信息信息
     * 
     * @param id 项目ID
     * @return 结果
     */
    @Override
    public int deleteProjectById(String id) {
        return projectMapper.deleteProjectById(id);
    }

    /**
     * 获取项目统计信息
     * 
     * @param id 项目ID
     * @return 项目统计信息
     */
    @Override
    public Project selectProjectStatistics(String id) {
        return projectMapper.selectProjectStatistics(id);
    }
    
    /**
     * 检查项目名称是否存在
     *
     * @param project 项目信息
     * @return 结果 true-存在 false-不存在
     */
    @Override
    public boolean checkProjectNameExists(Project project) {
        return projectMapper.checkProjectNameExists(project) > 0;
    }

    @Override
    public List<Project> selectProjectListByIds(List<String> ids) {
        return projectMapper.selectProjectListByIds(ids);
    }

    @Override
    public List<Project> selectProjectListByName(String name) {
        Project project = new Project();
        project.setProjectName(name);
        return projectMapper.selectProjectList(project);
    }
} 