package com.eden.room.service.impl;

import com.eden.room.domain.vo.BuildingTreeVO;
import com.eden.room.domain.vo.FloorTreeVO;
import com.eden.room.domain.vo.ProjectTreeVO;
import com.eden.room.domain.vo.RoomTreeVO;
import com.eden.room.mapper.ProjectTreeMapper;
import com.eden.room.service.ProjectTreeService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import java.util.List;

@Service
public class ProjectTreeServiceImpl implements ProjectTreeService {

    @Autowired
    private ProjectTreeMapper projectTreeMapper;

    @Override
    public List<ProjectTreeVO> getProjectTree(Integer level) {
        // 1. 查询所有项目
        List<ProjectTreeVO> projects = projectTreeMapper.selectProjects();
        
        // 如果只需要项目层级，直接返回
        if (level <= 1) {
            return projects;
        }
        
        // 2. 遍历项目，查询每个项目下的楼宇
        for (ProjectTreeVO project : projects) {
            List<BuildingTreeVO> buildings = projectTreeMapper.selectBuildingsByProjectId(project.getId());
            project.setBuildings(buildings);
            
            // 如果只需要楼宇层级，继续下一个项目
            if (level <= 2) {
                continue;
            }
            
            // 3. 遍历楼宇，查询每个楼宇下的楼层
            for (BuildingTreeVO building : buildings) {
                List<FloorTreeVO> floors = projectTreeMapper.selectFloorsByBuildingId(building.getId());
                building.setFloors(floors);
                
                // 如果只需要楼层层级，继续下一个楼宇
                if (level <= 3) {
                    continue;
                }
                
                // 4. 遍历楼层，查询每个楼层下的房源
                for (FloorTreeVO floor : floors) {
                    List<RoomTreeVO> rooms = projectTreeMapper.selectRoomsByFloorId(floor.getId());
                    floor.setRooms(rooms);
                }
            }
        }
        
        return projects;
    }
} 